@@ -56,7 +56,7 @@ class Autoshare(Entity):
             # Edit the sharelink
             sharelink.edit(type='view')
         """
-        from labstep.generic.entity.repository import entityRepository
+        from labstep.generic.entity.repository import editEntity
 
         options = {True: "edit", False: "none", None: None}
 
@@ -66,4 +66,4 @@ class Autoshare(Entity):
             "resource": options[resource_sharing],
             **extraParams,
         }
-        return entityRepository.editEntity(self, fields=fields)
+        return editEntity(self, fields=fields)
