@@ -2,15 +2,16 @@
 # -*- coding: utf-8 -*-
 # Author: Barney Walker <barney@labstep.com>
 from deprecated import deprecated
-from labstep.generic.primaryEntity.model import PrimaryEntity
+from labstep.generic.entityPrimary.model import EntityPrimary
+from labstep.generic.entityList.model import EntityList
 from labstep.entities.experimentProtocol.model import ExperimentProtocol
 from labstep.entities.experimentMaterial.model import ExperimentMaterial
 from labstep.entities.experimentTable.model import ExperimentTable
 from labstep.entities.experimentSignature.model import ExperimentSignature
-from labstep.service.helpers import getTime, listToClass
+from labstep.service.helpers import getTime
 
 
-class Experiment(PrimaryEntity):
+class Experiment(EntityPrimary):
     """
     Represents an Experiment on Labstep.
 
@@ -59,7 +60,7 @@ class Experiment(PrimaryEntity):
             my_experiment.edit(name='A New Experiment Name',
                                started_at='2018-06-06 12:05')
         """
-        from labstep.entities.experiment.repository import experimentRepository
+        import labstep.entities.experiment.repository as experimentRepository
 
         return experimentRepository.editExperiment(
             self, name=name, entry=entry, started_at=started_at, extraParams=extraParams
@@ -76,7 +77,7 @@ class Experiment(PrimaryEntity):
             my_experiment = user.getExperiment(17000)
             my_experiment.delete()
         """
-        from labstep.entities.experiment.repository import experimentRepository
+        import labstep.entities.experiment.repository as experimentRepository
 
         return experimentRepository.editExperiment(self, deleted_at=getTime())
 
@@ -91,7 +92,7 @@ class Experiment(PrimaryEntity):
             my_experiment = user.getExperiment(17000)
             print(my_experiment.getEntry())
         """
-        from labstep.generic.entity.repository import entityRepository
+        import labstep.generic.entity.repository as entityRepository
 
         return entityRepository.getEntity(
             self.__user__, ExperimentProtocol, self.root_experiment.id
@@ -124,7 +125,7 @@ class Experiment(PrimaryEntity):
             # Attach the Protocol to the Experiment
             my_experiment.addProtocol(my_protocol)
         """
-        from labstep.entities.experiment.repository import experimentRepository
+        import labstep.entities.experiment.repository as experimentRepository
 
         return experimentRepository.addProtocolToExperiment(self, protocol)
 
@@ -145,7 +146,7 @@ class Experiment(PrimaryEntity):
             protocols = entity.getProtocols()
             protocols[0].attributes()
         """
-        from labstep.generic.entity.repository import entityRepository
+        import labstep.generic.entity.repository as entityRepository
 
         return entityRepository.getEntities(
             self.__user__,
@@ -241,7 +242,7 @@ class Experiment(PrimaryEntity):
             List of the signatures added to the Experiment
         """
         exp = self.__user__.getExperiment(self.id)
-        return listToClass(exp.signatures, ExperimentSignature, self.__user__)
+        return EntityList(exp.signatures, ExperimentSignature, self.__user__)
 
     def addSignature(self, statement=None, lock=False):
         """
@@ -259,7 +260,7 @@ class Experiment(PrimaryEntity):
         :class:`~labstep.entities.experimentSignature.model.ExperimentSignature`
             The signature that has been added
         """
-        from labstep.generic.entity.repository import entityRepository
+        import labstep.generic.entity.repository as entityRepository
 
         params = {
             "statement": statement,
@@ -276,7 +277,7 @@ class Experiment(PrimaryEntity):
         -------
         List[:class:`~labstep.entities.experimentSignatureRequest.model.ExperimentSignatureRequest`]
         """
-        from labstep.entities.experimentSignatureRequest.repository import experimentSignatureRequestRepository
+        import labstep.entities.experimentSignatureRequest.repository as experimentSignatureRequestRepository
 
         return experimentSignatureRequestRepository.getExperimentSignatureRequests(self.__user__, self.id)
 
@@ -294,7 +295,7 @@ class Experiment(PrimaryEntity):
             Optional message to include in signature request email
 
         """
-        from labstep.entities.experimentSignatureRequest.repository import experimentSignatureRequestRepository
+        import labstep.entities.experimentSignatureRequest.repository as experimentSignatureRequestRepository
 
         return experimentSignatureRequestRepository.newExperimentSignatureRequest(self.__user__, self.id, user_id=user_id, message=message)
 
@@ -377,7 +378,7 @@ class Experiment(PrimaryEntity):
         -------
         None
         """
-        from labstep.entities.collection.repository import collectionRepository
+        import labstep.entities.collection.repository as collectionRepository
 
         return collectionRepository.addToCollection(self, collection_id=collection_id)
 
@@ -385,7 +386,7 @@ class Experiment(PrimaryEntity):
         """
         Returns the list of collections the protocol is in.
         """
-        from labstep.entities.collection.repository import collectionRepository
+        import labstep.entities.collection.repository as collectionRepository
 
         return collectionRepository.getAttachedCollections(self)
 
@@ -399,7 +400,7 @@ class Experiment(PrimaryEntity):
             The id of the collection to remove from
 
         """
-        from labstep.entities.collection.repository import collectionRepository
+        import labstep.entities.collection.repository as collectionRepository
 
         return collectionRepository.removeFromCollection(self, collection_id)
 
@@ -525,7 +526,7 @@ class Experiment(PrimaryEntity):
             experiment = user.getExperiment(17000)
             experiment.export('/my_folder')
         """
-        from labstep.entities.experiment.repository import experimentRepository
+        import labstep.entities.experiment.repository as experimentRepository
 
         return experimentRepository.exportExperiment(self, path)
 
