@@ -42,7 +42,7 @@ class ExperimentMaterial(Entity):
             exp_protocol_materials = exp_protocol.getMaterials()
             exp_protocol_materials[0].edit(amount=1.7, units='ml')
         """
-        from labstep.entities.experimentMaterial.repository import experimentMaterialRepository
+        import labstep.entities.experimentMaterial.repository as experimentMaterialRepository
 
         return experimentMaterialRepository.editExperimentMaterial(self,
                                                                    name=name,
