@@ -23,7 +23,7 @@ class ExperimentStep(Entity):
         :class:`~labstep.entities.experimentStep.model.ExperimentStep`
             An object representing the edited Experiment Step.
         """
-        from labstep.generic.entity.repository import entityRepository
+        import labstep.generic.entity.repository as entityRepository
 
         params = {"ended_at": completed_at}
         return entityRepository.editEntity(self, params)
@@ -71,7 +71,7 @@ class ExperimentStep(Entity):
             exp_protocol_steps = exp_protocol.getSteps()
             exp_protocol_steps[0].addComment('This step failed')
         """
-        from labstep.entities.comment.repository import commentRepository
+        import labstep.entities.comment.repository as commentRepository
 
         return commentRepository.addCommentWithFile(self, body, filepath)
 
@@ -99,6 +99,6 @@ class ExperimentStep(Entity):
             exp_protocol_steps = exp_protocol.getSteps()
             exp_protocol_steps[0].getComments()
         """
-        from labstep.entities.comment.repository import commentRepository
+        import labstep.entities.comment.repository as commentRepository
 
         return commentRepository.getComments(self, count)
