@@ -35,7 +35,7 @@ class ExperimentTimer(Entity):
             exp_protocol_timers = exp_protocol.getTimers()
             exp_protocol_timers[0].edit(minutes=1, seconds=7)
         """
-        from labstep.generic.entity.repository import entityRepository
+        import labstep.generic.entity.repository as entityRepository
 
         fields = {}
 
