@@ -21,7 +21,7 @@ class File(Entity):
             file = entities[0]
             data = file.getData()
         """
-        from labstep.entities.file.repository import fileRepository
+        import labstep.entities.file.repository as fileRepository
 
         return fileRepository.downloadFile(self.__user__, self.id)
 
@@ -80,6 +80,6 @@ class File(Entity):
             file = user.getFile(17000)
             file.export('/my_folder')
         """
-        from labstep.entities.file.repository import fileRepository
+        import labstep.entities.file.repository as fileRepository
 
         return fileRepository.exportFile(self, path)
