@@ -2,10 +2,10 @@
 # -*- coding: utf-8 -*-
 # Author: Thomas Bullier <thomas@labstep.com>
 
-from labstep.generic.primaryEntity.model import PrimaryEntity
+from labstep.generic.entity.model import Entity
 
 
-class JupyterNotebook(PrimaryEntity):
+class JupyterNotebook(Entity):
     """
     Represents an JupyterNotebook on Labstep.
     """
@@ -38,7 +38,7 @@ class JupyterNotebook(PrimaryEntity):
             my_jupyterNotebook = user.getJupyterNotebook("872b3e7e-e21f-4403-9ef3-3650fe0d86ba")
             my_jupyterNotebook.edit(data='{test: 42}')
         """
-        from labstep.entities.jupyterNotebook.repository import jupyterNotebookRepository
+        import labstep.entities.jupyterNotebook.repository as jupyterNotebookRepository
 
         return jupyterNotebookRepository.editJupyterNotebook(
             self, name=name, status=status, data=data, extraParams=extraParams
