@@ -69,6 +69,7 @@ class Metadata(Entity):
     """
 
     __entityName__ = "metadata"
+    __searchKey__ = "label"
 
     def edit(self, fieldName=None, value=None, extraParams={}):
         """
@@ -92,7 +93,7 @@ class Metadata(Entity):
 
             metadata.edit(value='2.50')
         """
-        from labstep.entities.metadata.repository import metadataRepository
+        import labstep.entities.metadata.repository as metadataRepository
 
         return metadataRepository.editMetadata(
             self, fieldName, value, extraParams=extraParams
@@ -108,7 +109,7 @@ class Metadata(Entity):
 
             metadata.delete()
         """
-        from labstep.entities.metadata.repository import metadataRepository
+        import labstep.entities.metadata.repository as metadataRepository
 
         return metadataRepository.editMetadata(
             self, extraParams={"deleted_at": getTime()}
