@@ -2,13 +2,13 @@
 # -*- coding: utf-8 -*-
 # Author: Barney Walker <barney@labstep.com>
 
-from labstep.generic.primaryEntity.model import PrimaryEntity
+from labstep.generic.entityWithSharing.model import EntityWithSharing
 from labstep.service.helpers import getTime
 from labstep.entities.resourceTemplate.model import ResourceTemplate
 from labstep.entities.resourceItem.model import ResourceItem
 
 
-class ResourceCategory(PrimaryEntity):
+class ResourceCategory(EntityWithSharing):
     """
     Represents a Resource Category on Labstep.
 
@@ -45,7 +45,7 @@ class ResourceCategory(PrimaryEntity):
             my_resource_category = user.getResourceCategory(17000)
             my_resource_category.edit(name='A New ResourceCategory Name')
         """
-        from labstep.entities.resourceCategory.repository import resourceCategoryRepository
+        import labstep.entities.resourceCategory.repository as resourceCategoryRepository
 
         return resourceCategoryRepository.editResourceCategory(
             self, name, extraParams=extraParams
@@ -62,7 +62,7 @@ class ResourceCategory(PrimaryEntity):
             my_resource_category = user.getResourceCategory(17000)
             my_resource_category.delete()
         """
-        from labstep.entities.resourceCategory.repository import resourceCategoryRepository
+        import labstep.entities.resourceCategory.repository as resourceCategoryRepository
 
         return resourceCategoryRepository.editResourceCategory(
             self, deleted_at=getTime()
@@ -125,7 +125,7 @@ class ResourceCategory(PrimaryEntity):
         """
         self.update()
         if self.resource_item_template is None:
-            from labstep.entities.resourceItem.repository import resourceItemRepository
+            import labstep.entities.resourceItem.repository as resourceItemRepository
 
             resourceItemRepository.newResourceItem(
                 self.__user__, self.id, extraParams={"is_template": 1}
