@@ -54,7 +54,7 @@ class ResourceTemplate(Entity):
             metadata = my_resource_category.addMetadata("Refractive Index",
                                                         value="1.73")
         """
-        from labstep.entities.metadata.repository import metadataRepository
+        import labstep.entities.metadata.repository as metadataRepository
 
         return metadataRepository.addMetadataTo(
             self,
@@ -85,6 +85,6 @@ class ResourceTemplate(Entity):
             metadatas = entity.getMetadata()
             metadatas[0].attributes()
         """
-        from labstep.entities.metadata.repository import metadataRepository
+        import labstep.entities.metadata.repository as metadataRepository
 
         return metadataRepository.getMetadata(self)
