@@ -3,7 +3,7 @@
 # Author: Barney Walker <barney@labstep.com>
 
 import os
-from labstep.entities.user.repository import userRepository
+import labstep.entities.user.repository as userRepository
 
 
 def newUser(
