@@ -84,7 +84,7 @@ class User(Entity):
 
             entity = user.getExperiment(17000)
         """
-        from labstep.entities.experiment.repository import experimentRepository
+        import labstep.entities.experiment.repository as experimentRepository
 
         return experimentRepository.getExperiment(self, experiment_id)
 
@@ -108,7 +108,7 @@ class User(Entity):
 
             entity = user.getProtocol(17000)
         """
-        from labstep.entities.protocol.repository import protocolRepository
+        import labstep.entities.protocol.repository as protocolRepository
 
         return protocolRepository.getProtocol(self, protocol_id)
 
@@ -132,7 +132,7 @@ class User(Entity):
 
             entity = user.getResource(17000)
         """
-        from labstep.entities.resource.repository import resourceRepository
+        import labstep.entities.resource.repository as resourceRepository
 
         return resourceRepository.getResource(self, resource_id)
 
@@ -156,7 +156,7 @@ class User(Entity):
 
             entity = user.getResourceItem(17000)
         """
-        from labstep.entities.resourceItem.repository import resourceItemRepository
+        import labstep.entities.resourceItem.repository as resourceItemRepository
 
         return resourceItemRepository.getResourceItem(self, resource_item_id)
 
@@ -180,7 +180,7 @@ class User(Entity):
 
             entity = user.getResourceCategory(17000)
         """
-        from labstep.entities.resourceCategory.repository import resourceCategoryRepository
+        import labstep.entities.resourceCategory.repository as resourceCategoryRepository
 
         return resourceCategoryRepository.getResourceCategory(
             self, resource_category_id
@@ -206,7 +206,7 @@ class User(Entity):
 
             entity = user.getResourceLocation(17000)
         """
-        from labstep.entities.resourceLocation.repository import resourceLocationRepository
+        import labstep.entities.resourceLocation.repository as resourceLocationRepository
 
         return resourceLocationRepository.getResourceLocation(
             self, resource_location_id
@@ -232,7 +232,7 @@ class User(Entity):
 
             entity = user.getOrderRequest(17000)
         """
-        from labstep.entities.orderRequest.repository import orderRequestRepository
+        import labstep.entities.orderRequest.repository as orderRequestRepository
 
         return orderRequestRepository.getOrderRequest(self, order_request_id)
 
@@ -256,7 +256,7 @@ class User(Entity):
 
             entity = user.getWorkspace(17000)
         """
-        from labstep.entities.workspace.repository import workspaceRepository
+        import labstep.entities.workspace.repository as workspaceRepository
 
         return workspaceRepository.getWorkspace(self, workspace_id)
 
@@ -275,7 +275,7 @@ class User(Entity):
 
             organization = user.getOrganization()
         """
-        from labstep.entities.organization.repository import organizationRepository
+        import labstep.entities.organization.repository as organizationRepository
 
         if len(self.user_organizations) > 0:
 
@@ -303,7 +303,7 @@ class User(Entity):
 
             entity = user.getFile(17000)
         """
-        from labstep.entities.file.repository import fileRepository
+        import labstep.entities.file.repository as fileRepository
 
         return fileRepository.getFile(self, file_id)
 
@@ -327,7 +327,7 @@ class User(Entity):
 
             entity = user.getDevice(17000)
         """
-        from labstep.entities.device.repository import deviceRepository
+        import labstep.entities.device.repository as deviceRepository
 
         return deviceRepository.getDevice(self, device_id)
 
@@ -379,7 +379,7 @@ class User(Entity):
                                          created_at_to='2019-01-31',
                                          tag_id=800)
         """
-        from labstep.entities.experiment.repository import experimentRepository
+        import labstep.entities.experiment.repository as experimentRepository
 
         return experimentRepository.getExperiments(
             self,
@@ -438,7 +438,7 @@ class User(Entity):
                                        created_at_to='2019-01-31',
                                        tag_id=800)
         """
-        from labstep.entities.protocol.repository import protocolRepository
+        import labstep.entities.protocol.repository as protocolRepository
 
         return protocolRepository.getProtocols(
             self,
@@ -478,7 +478,7 @@ class User(Entity):
             entity = user.getResources(search_query='bacteria',
                                        tag_id=800)
         """
-        from labstep.entities.resource.repository import resourceRepository
+        import labstep.entities.resource.repository as resourceRepository
 
         return resourceRepository.getResources(
             self,
@@ -517,7 +517,7 @@ class User(Entity):
             entity = user.getResourceCategorys(search_query='properties',
                                                tag_id=800)
         """
-        from labstep.entities.resourceCategory.repository import resourceCategoryRepository
+        import labstep.entities.resourceCategory.repository as resourceCategoryRepository
 
         return resourceCategoryRepository.getResourceCategorys(
             self,
@@ -550,7 +550,7 @@ class User(Entity):
 
             entity = user.getResourceLocations(search_query='fridge')
         """
-        from labstep.entities.resourceLocation.repository import resourceLocationRepository
+        import labstep.entities.resourceLocation.repository as resourceLocationRepository
 
         return resourceLocationRepository.getResourceLocations(
             self, count=count, search_query=search_query, extraParams=extraParams
@@ -579,7 +579,7 @@ class User(Entity):
 
             entity = user.getResourceItems(search_query='batch #5')
         """
-        from labstep.entities.resourceItem.repository import resourceItemRepository
+        import labstep.entities.resourceItem.repository as resourceItemRepository
 
         return resourceItemRepository.getResourceItems(
             self, count=count, search_query=search_query, extraParams=extraParams
@@ -616,7 +616,7 @@ class User(Entity):
 
             entity = user.getOrderRequests(name='polymerase')
         """
-        from labstep.entities.orderRequest.repository import orderRequestRepository
+        import labstep.entities.orderRequest.repository as orderRequestRepository
 
         return orderRequestRepository.getOrderRequests(
             self,
@@ -655,7 +655,7 @@ class User(Entity):
 
             entity = user.getTags(search_query='bacteria')
         """
-        from labstep.entities.tag.repository import tagRepository
+        import labstep.entities.tag.repository as tagRepository
 
         return tagRepository.getTags(
             self,
@@ -689,7 +689,7 @@ class User(Entity):
 
             entity = user.getWorkspaces(name='bacteria')
         """
-        from labstep.entities.workspace.repository import workspaceRepository
+        import labstep.entities.workspace.repository as workspaceRepository
 
         return workspaceRepository.getWorkspaces(
             self, count=count, search_query=search_query, extraParams=extraParams
@@ -723,7 +723,7 @@ class User(Entity):
 
             entity = user.getDevices(search_query='microscope')
         """
-        from labstep.entities.device.repository import deviceRepository
+        import labstep.entities.device.repository as deviceRepository
 
         return deviceRepository.getDevices(
             self, count=count, search_query=search_query, extraParams=extraParams
@@ -753,7 +753,7 @@ class User(Entity):
 
             entity = user.newExperiment(name='The Synthesis of Aspirin')
         """
-        from labstep.entities.experiment.repository import experimentRepository
+        import labstep.entities.experiment.repository as experimentRepository
 
         return experimentRepository.newExperiment(
             self, name, entry=entry, extraParams=extraParams
@@ -779,7 +779,7 @@ class User(Entity):
 
             entity = user.newProtocol(name='Synthesising Aspirin')
         """
-        from labstep.entities.protocol.repository import protocolRepository
+        import labstep.entities.protocol.repository as protocolRepository
 
         return protocolRepository.newProtocol(self, name, extraParams=extraParams)
 
@@ -806,7 +806,7 @@ class User(Entity):
 
             entity = user.newResource(name='salicylic acid')
         """
-        from labstep.entities.resource.repository import resourceRepository
+        import labstep.entities.resource.repository as resourceRepository
 
         return resourceRepository.newResource(self, name, resource_category_id=resource_category_id, extraParams=extraParams)
 
@@ -830,7 +830,7 @@ class User(Entity):
 
             entity = user.newResourceCategory(name='Chemical')
         """
-        from labstep.entities.resourceCategory.repository import resourceCategoryRepository
+        import labstep.entities.resourceCategory.repository as resourceCategoryRepository
 
         return resourceCategoryRepository.newResourceCategory(
             self, name, extraParams=extraParams
@@ -863,7 +863,7 @@ class User(Entity):
 
             entity = user.newResourceLocation(name='Fridge A')
         """
-        from labstep.entities.resourceLocation.repository import resourceLocationRepository
+        import labstep.entities.resourceLocation.repository as resourceLocationRepository
 
         return resourceLocationRepository.newResourceLocation(
             self, name, outer_location_id=outer_location_id, extraParams=extraParams
@@ -893,7 +893,7 @@ class User(Entity):
             my_resource = user.getResource(17000)
             entity = user.newOrderRequest(my_resource.id, quantity=2)
         """
-        from labstep.entities.orderRequest.repository import orderRequestRepository
+        import labstep.entities.orderRequest.repository as orderRequestRepository
 
         return orderRequestRepository.newOrderRequest(
             self, resource_id=resource_id, quantity=quantity, extraParams=extraParams
@@ -923,7 +923,7 @@ class User(Entity):
 
             entity = user.newTag(name='Aspirin')
         """
-        from labstep.entities.tag.repository import tagRepository
+        import labstep.entities.tag.repository as tagRepository
 
         return tagRepository.newTag(self, name, type=type, extraParams=extraParams)
 
@@ -947,11 +947,11 @@ class User(Entity):
 
             entity = user.newWorkspace(name='Aspirin Project')
         """
-        from labstep.entities.workspace.repository import workspaceRepository
+        import labstep.entities.workspace.repository as workspaceRepository
 
         return workspaceRepository.newWorkspace(self, name, extraParams=extraParams)
 
-    def newFile(self, filepath, rawData=None, extraParams={}):
+    def newFile(self, filepath=None, rawData=None, extraParams={}):
         """
         Upload a file to the Labstep entity Data.
 
@@ -966,22 +966,22 @@ class User(Entity):
 
             entity = user.newFile('./structure_of_aspirin.png')
         """
-        from labstep.entities.file.repository import fileRepository
+        import labstep.entities.file.repository as fileRepository
 
         return fileRepository.newFile(self, filepath, rawData=rawData, extraParams=extraParams)
 
-    def newCollection(self, name, type="experiment"):
+    def newCollection(self, name, type="experiment", extraParams={}):
         """
         Create a new Collection for Experiments (or Protocols)
 
         Parameters
         ----------
         type (str)
-            The filepath to the file to attach.
+            The type of collection to create ("experiment" or "protocol")
         """
-        from labstep.entities.collection.repository import collectionRepository
+        import labstep.entities.collection.repository as collectionRepository
 
-        return collectionRepository.newCollection(self, name=name, type=type)
+        return collectionRepository.newCollection(self, name=name, type=type, extraParams=extraParams)
 
     def newDevice(self, name, extraParams={}):
         """
@@ -1003,7 +1003,7 @@ class User(Entity):
 
             entity = user.newDevice(name='Microscope A')
         """
-        from labstep.entities.device.repository import deviceRepository
+        import labstep.entities.device.repository as deviceRepository
 
         return deviceRepository.newDevice(self, name, extraParams)
 
@@ -1047,7 +1047,7 @@ class User(Entity):
 
             entity = user.getJupyterInstance("872b3e7e-e21f-4403-9ef3-3650fe0d86ba")
         """
-        from labstep.entities.jupyterInstance.repository import jupyterInstanceRepository
+        import labstep.entities.jupyterInstance.repository as jupyterInstanceRepository
 
         return jupyterInstanceRepository.getJupyterInstance(self, jupyterInstanceGuid)
 
@@ -1071,6 +1071,6 @@ class User(Entity):
 
             entity = user.getJupyterNotebook("872b3e7e-e21f-4403-9ef3-3650fe0d86ba")
         """
-        from labstep.entities.jupyterNotebook.repository import jupyterNotebookRepository
+        import labstep.entities.jupyterNotebook.repository as jupyterNotebookRepository
 
         return jupyterNotebookRepository.getJupyterNotebook(self, jupyterNotebookGuid)
