@@ -46,7 +46,7 @@ class Workspace(Entity):
             my_workspace = user.getWorkspace(17000)
             my_workspace.edit(name='A New Workspace Name')
         """
-        from labstep.entities.workspace.repository import workspaceRepository
+        import labstep.entities.workspace.repository as workspaceRepository
 
         return workspaceRepository.editWorkspace(self, name, extraParams=extraParams)
 
@@ -61,7 +61,7 @@ class Workspace(Entity):
             my_workspace = user.getWorkspace(17000)
             my_workspace.delete()
         """
-        from labstep.entities.workspace.repository import workspaceRepository
+        import labstep.entities.workspace.repository as workspaceRepository
 
         return workspaceRepository.editWorkspace(self, deleted_at=getTime())
 
@@ -111,7 +111,7 @@ class Workspace(Entity):
                                               created_at_to='2019-01-31',
                                               tag_id=800)
         """
-        from labstep.entities.experiment.repository import experimentRepository
+        import labstep.entities.experiment.repository as experimentRepository
 
         extraParams = {"group_id": self.id, **extraParams}
 
@@ -171,7 +171,7 @@ class Workspace(Entity):
                                             created_at_to='2019-01-31',
                                             tag_id=800)
         """
-        from labstep.entities.protocol.repository import protocolRepository
+        import labstep.entities.protocol.repository as protocolRepository
 
         extraParams = {"group_id": self.id, **extraParams}
 
@@ -212,7 +212,7 @@ class Workspace(Entity):
             entity = workspace.getResources(search_query='bacteria',
                                             tag_id=800)
         """
-        from labstep.entities.resource.repository import resourceRepository
+        import labstep.entities.resource.repository as resourceRepository
 
         extraParams = {"group_id": self.id, **extraParams}
 
@@ -248,7 +248,7 @@ class Workspace(Entity):
             entity = workspace.getResourceCategorys(search_query='properties',
                                                     tag_id=800)
         """
-        from labstep.entities.resourceCategory.repository import resourceCategoryRepository
+        import labstep.entities.resourceCategory.repository as resourceCategoryRepository
 
         extraParams = {"group_id": self.id, **extraParams}
 
@@ -280,7 +280,7 @@ class Workspace(Entity):
             entity = workspace.getResourceLocations(search_query='properties',
                                                     tag_id=800)
         """
-        from labstep.entities.resourceLocation.repository import resourceLocationRepository
+        import labstep.entities.resourceLocation.repository as resourceLocationRepository
 
         extraParams = {"group_id": self.id, **extraParams}
 
@@ -314,7 +314,7 @@ class Workspace(Entity):
 
             entity = workspace.getOrderRequests(name='polymerase')
         """
-        from labstep.entities.orderRequest.repository import orderRequestRepository
+        import labstep.entities.orderRequest.repository as orderRequestRepository
 
         extraParams = {"group_id": self.id, **extraParams}
 
@@ -354,7 +354,7 @@ class Workspace(Entity):
 
             entity = workspace.getTags(search_query='bacteria')
         """
-        from labstep.entities.tag.repository import tagRepository
+        import labstep.entities.tag.repository as tagRepository
 
         extraParams = {"group_id": self.id, **extraParams}
 
@@ -384,7 +384,7 @@ class Workspace(Entity):
 
             newMember = workspace.addMember(user_id=123)
         """
-        from labstep.entities.workspaceMember.repository import workspaceMemberRepository
+        import labstep.entities.workspaceMember.repository as workspaceMemberRepository
         return workspaceMemberRepository.addMember(self.__user__, workspace_id=self.id, user_id=user_id)
 
     def getMembers(self, count=100, search_query=None, extraParams={}):
@@ -410,7 +410,7 @@ class Workspace(Entity):
 
             members = workspace.getMembers(search_query='john')
         """
-        from labstep.entities.workspaceMember.repository import workspaceMemberRepository
+        import labstep.entities.workspaceMember.repository as workspaceMemberRepository
         return workspaceMemberRepository.getMembers(self.__user__, workspace_id=self.id, search_query=search_query, extraParams=extraParams)
 
     def getFiles(self, count=100, search_query=None, file_type=None, extraParams={}):
@@ -440,7 +440,7 @@ class Workspace(Entity):
 
             files = workspace.getFiles(search_query='bacteria')
         """
-        from labstep.entities.file.repository import fileRepository
+        import labstep.entities.file.repository as fileRepository
 
         extraParams = {"group_id": self.id, **extraParams}
 
@@ -471,7 +471,7 @@ class Workspace(Entity):
 
             devices = workspace.getDevices(search_query='microscope')
         """
-        from labstep.entities.device.repository import deviceRepository
+        import labstep.entities.device.repository as deviceRepository
 
         extraParams = {"group_id": self.id, **extraParams}
 
@@ -515,7 +515,7 @@ class Workspace(Entity):
 
         """
 
-        from labstep.entities.sharelink.repository import shareLinkRepository
+        import labstep.entities.sharelink.repository as shareLinkRepository
         return shareLinkRepository.getSharelink(self)
 
     def getCollections(
@@ -547,7 +547,7 @@ class Workspace(Entity):
             entity = workspace.getCollections(search_query='bacteria')
         """
         extraParams = {"group_id": self.id, **extraParams}
-        from labstep.entities.collection.repository import collectionRepository
+        import labstep.entities.collection.repository as collectionRepository
 
         return collectionRepository.getCollections(
             self.__user__, count, type, search_query, extraParams=extraParams
@@ -573,7 +573,7 @@ class Workspace(Entity):
         collection
             An object representing the new Labstep Collection.
         """
-        from labstep.entities.collection.repository import collectionRepository
+        import labstep.entities.collection.repository as collectionRepository
 
         return collectionRepository.newCollection(
             self.__user__, name=name, type=type, extraParams={
@@ -585,7 +585,7 @@ class Workspace(Entity):
         Sets this workspace as the default workspace for the active user.
         """
         member = WorkspaceMember(self.logged_user_user_group, self.__user__)
-        from labstep.generic.entity.repository import entityRepository
+        import labstep.generic.entity.repository as entityRepository
 
         return entityRepository.editEntity(member, {"is_home": True})
 
@@ -624,7 +624,7 @@ class Workspace(Entity):
         self.update()
 
         if self.security_policy is None:
-            from labstep.generic.entity.repository import entityRepository
+            import labstep.generic.entity.repository as entityRepository
 
             policy = entityRepository.newEntity(
                 self.__user__,
