@@ -29,7 +29,7 @@ class Entity:
         """
         Fetches the most up-to-date version of the entity from Labstep.
         """
-        from labstep.generic.entity.repository import entityRepository
+        import labstep.generic.entity.repository as entityRepository
 
         data = entityRepository.getEntity(
             self.__user__, type(self), self.id).__data__
@@ -52,5 +52,5 @@ class Entity:
             experiment = user.getExperiment(17000)
             experiment.export('/my_folder')
         """
-        from labstep.generic.entity.repository import entityRepository
+        import labstep.generic.entity.repository as entityRepository
         return entityRepository.exportEntity(self, rootPath, folderName=folderName)
